@@ -192,7 +192,6 @@ dee_filter_model_constructed (GObject *object)
 {
   DeeFilterModelPrivate *priv = DEE_FILTER_MODEL (object)->priv;
   DeeFilter             *filter = priv->filter;
-  guint                  n_columns;
   
   if (filter == NULL)
     {
@@ -201,8 +200,7 @@ dee_filter_model_constructed (GObject *object)
       return;
     }
   
-  g_object_get (object, "back-end", &(priv->orig_model), NULL);  
-  n_columns = dee_model_get_n_columns (priv->orig_model);
+  g_object_get (object, "back-end", &(priv->orig_model), NULL);
   
   /* Map the end iter of the orig_model to the end iter of our iter list */
   g_hash_table_insert (priv->iter_map,
