@@ -367,13 +367,10 @@ dee_sequence_model_remove (DeeModel     *self,
                            DeeModelIter *iter_)
 {
   DeeSequenceModel        *_self = (DeeSequenceModel *)self;
-  DeeSequenceModelPrivate *priv;
   GSequenceIter           *iter = (GSequenceIter *)iter_;
 
   g_return_if_fail (DEE_IS_SEQUENCE_MODEL (_self));
   g_return_if_fail (iter != NULL);
-  
-  priv = _self->priv;
 
   if (iter_ == dee_model_get_last_iter (self))
     return;
@@ -452,7 +449,6 @@ dee_sequence_model_set_value_silently (DeeModel      *self,
                                        GVariant      *value)
 {
   DeeSequenceModel        *_self = (DeeSequenceModel *)self;
-  DeeSequenceModelPrivate *priv;
   GPtrArray               *row;
 
   g_return_if_fail (DEE_IS_SEQUENCE_MODEL (_self));
@@ -460,10 +456,17 @@ dee_sequence_model_set_value_silently (DeeModel      *self,
   g_return_if_fail (column < dee_model_get_n_columns (self));
   g_return_if_fail (g_variant_type_equal (g_variant_get_type (value), G_VARIANT_TYPE (dee_model_get_column_schema (self, column))));
   g_return_if_fail (value != NULL);
-  
-  priv = _self->priv;
 
   row = g_sequence_get ((GSequenceIter *) iter);
+
+  if (G_UNLIKELY (row == NULL))
+      {
+        g_critical ("Unable to set value. NULL row data in DeeSequenceModel@%p "
+                    "at position %u. The row has probably been removed",
+                    self, dee_model_get_position (self, iter));
+        return;
+      }
+
   if (g_ptr_array_index (row, column) != NULL)
     g_variant_unref (g_ptr_array_index (row, column));
 
@@ -486,8 +489,9 @@ dee_sequence_model_get_value (DeeModel     *self,
   row = g_sequence_get ((GSequenceIter *) iter);
   if (G_UNLIKELY (row == NULL))
     {
-      g_critical ("Internal error: NULL row in DeeSequenceModel@%p"
-                  " at position %u", self, dee_model_get_position (self, iter));
+      g_critical ("Unable to get value. NULL row data in DeeSequenceModel@%p "
+                  "at position %u. The row has probably been removed",
+                  self, dee_model_get_position (self, iter));
       return NULL;
     }
 
@@ -771,6 +775,10 @@ dee_sequence_model_free_row (DeeSequenceModel *self,
 
   /* Free the row itself */
   g_ptr_array_unref (row);
+
+  /* Set the row data to NULL to help debugging for consumers accessing
+   * removed rows*/
+  g_sequence_set (iter, NULL);
 }
 
 static void
@@ -790,6 +798,27 @@ dee_sequence_model_find_tag (DeeSequenceModel  *self,
   n_cols = dee_model_get_n_columns (DEE_MODEL (self));
   tag_offset = GPOINTER_TO_UINT (tag);
 
+  if (G_UNLIKELY (priv->sequence == NULL))
+    {
+      g_critical ("Access to freed DeeSequenceModel detected "
+                  "when looking up tag on DeeSequenceModel@%p", self);
+      goto not_found;
+    }
+
+  if (G_UNLIKELY (priv->tags == NULL))
+    {
+      g_critical ("Unable to look up tag. No tags registered on "
+                  "DeeSequenceModel@%p", self);
+      goto not_found;
+    }
+
+  if (G_UNLIKELY (row == NULL))
+    {
+      g_critical ("Unable to look up tag. No row data. "
+                  "The row has probably been removed ");
+            goto not_found;
+    }
+
   /* Find tag at right offset */
   row_tag_iter = g_ptr_array_index (row, n_cols);
   tag_iter = priv->tags;
@@ -805,13 +834,16 @@ dee_sequence_model_find_tag (DeeSequenceModel  *self,
     {
       g_critical ("Unable to find tag %u for %s@%p",
                   tag_offset, G_OBJECT_TYPE_NAME (self), self);
-      *out_row_tag = NULL;
-      *out_tag = NULL;
-      return;
+      goto not_found;
     }
 
   *out_row_tag = row_tag_iter;
   *out_tag = tag_iter;
+  return;
+
+  not_found:
+    *out_row_tag = NULL;
+    *out_tag = NULL;
 }
 
 /*
