@@ -190,6 +190,9 @@ dee_serializable_model_finalize (GObject *object)
 {
   DeeSerializableModelPrivate *priv = DEE_SERIALIZABLE_MODEL (object)->priv;
 
+  priv->n_columns = 0;
+  priv->seqnum = 0;
+
   if (priv->column_schemas != NULL)
     {
       g_strfreev (priv->column_schemas);
@@ -866,7 +869,7 @@ dee_serializable_model_serialize (DeeSerializable *self)
   GVariantBuilder         aav, clone;
   GVariant               *val, *tt, *schema;
   DeeModelIter           *iter;
-  guint                   i, j, n_rows, n_columns;
+  guint                   i, j, n_columns;
   guint64                 last_seqnum;
 
   g_return_val_if_fail (DEE_IS_SERIALIZABLE_MODEL (self), FALSE);
@@ -874,7 +877,6 @@ dee_serializable_model_serialize (DeeSerializable *self)
   trace_object (self, "Building clone");
 
   _self = DEE_MODEL (self);
-  n_rows = dee_model_get_n_rows (_self);
   n_columns = dee_model_get_n_columns (_self);
 
   g_variant_builder_init (&aav, G_VARIANT_TYPE ("aav"));
@@ -910,7 +912,7 @@ dee_serializable_model_serialize (DeeSerializable *self)
   g_variant_builder_add_value (&clone, g_variant_builder_end (&aav));
   g_variant_builder_add_value (&clone, tt);
 
-  trace_object (self, "Serialized with %i rows", n_rows);
+  trace_object (self, "Serialized with %i rows", dee_model_get_n_rows (_self));
 
   return g_variant_builder_end (&clone);
 }
