@@ -1459,7 +1459,7 @@ dee_shared_model_serialize (DeeSerializable *self)
   GVariantBuilder         aav, au, ay, clone;
   GVariant               *val, *tt, *schema;
   DeeModelIter           *iter;
-  guint                   i, j, n_rows, n_columns;
+  guint                   i, j, n_columns;
   guint64                 last_seqnum;
   
   g_return_val_if_fail (DEE_IS_SHARED_MODEL (self), FALSE);
@@ -1468,7 +1468,6 @@ dee_shared_model_serialize (DeeSerializable *self)
                 dee_model_get_n_rows (DEE_MODEL (self)));
 
   _self = DEE_MODEL (self);
-  n_rows = dee_model_get_n_rows (DEE_MODEL (self));
   n_columns = dee_model_get_n_columns (DEE_MODEL (self));
 
   g_variant_builder_init (&aav, G_VARIANT_TYPE ("aav"));
