@@ -31,16 +31,20 @@
 
 #include <dee-peer.h>
 #include <dee-model.h>
-#include <dee-versioned-model.h>
+#include <dee-serializable-model.h>
 #include <dee-proxy-model.h>
 #include <dee-sequence-model.h>
 #include <dee-shared-model.h>
 #include <dee-filter-model.h>
+#include <dee-filters.h>
 #include <dee-index.h>
 #include <dee-hash-index.h>
 #include <dee-term-list.h>
 #include <dee-result-set.h>
 #include <dee-analyzers.h>
+#include <dee-serializable.h>
+#include <dee-resource-manager.h>
+#include <dee-file-resource-manager.h>
 
 #undef _DEE_H_INSIDE
 
