@@ -39,7 +39,9 @@ static void test_discard_all                   (FilterFixture *fix,
                                                 gconstpointer  data);
 static void test_discard_all_append_notify     (FilterFixture *fix,
                                                 gconstpointer  data);
-static void test_collator                      (FilterFixture *fix,
+static void test_collator_asc                  (FilterFixture *fix,
+                                                gconstpointer  data);
+static void test_collator_desc                  (FilterFixture *fix,
                                                 gconstpointer  data);
 static void test_key                           (FilterFixture *fix,
                                                 gconstpointer  data);
@@ -62,8 +64,10 @@ test_filter_model_create_suite (void)
               setup, test_discard_all, teardown);
   g_test_add (DOMAIN"/DiscardAllAppendNotify", FilterFixture, 0,
               setup, test_discard_all_append_notify, teardown);
-  g_test_add (DOMAIN"/Collator", FilterFixture, 0,
-              setup, test_collator, teardown);
+  g_test_add (DOMAIN"/CollatorAscending", FilterFixture, 0,
+              setup, test_collator_asc, teardown);
+  g_test_add (DOMAIN"/CollatorDescending", FilterFixture, 0,
+              setup, test_collator_desc, teardown);
   g_test_add (DOMAIN"/Key", FilterFixture, 0,
               setup, test_key, teardown);
   g_test_add (DOMAIN"/Any", FilterFixture, 0,
@@ -301,9 +305,9 @@ test_discard_all_append_notify (FilterFixture *fix, gconstpointer data)
   g_object_unref (m);
 }
 
-/* Test dee_filter_new_collator() */
+/* Test dee_filter_new_collator() ascending */
 static void
-test_collator (FilterFixture *fix, gconstpointer data)
+test_collator_asc (FilterFixture *fix, gconstpointer data)
 {
   DeeModelIter *r0, *r1, *r2, *r3, *r4, *r5;
   DeeFilter    *collator = dee_filter_new_collator (1);
@@ -336,12 +340,57 @@ test_collator (FilterFixture *fix, gconstpointer data)
   /* Appending to the end of the sorted model is a special case in the code,
    * so double check on that... */
   dee_model_append (fix->model, 5, "Zzzz");
+  r0 = dee_model_get_iter_at_row (m, 0);
   r5 = dee_model_get_iter_at_row (m, 5);
+  g_assert_cmpstr ("Four", ==, dee_model_get_string (m, r0, 1));
   g_assert_cmpstr ("Zzzz", ==, dee_model_get_string (m, r5, 1));
 
   g_object_unref (m);
 }
 
+/* Test dee_filter_new_collator_desc() descending*/
+static void
+test_collator_desc (FilterFixture *fix, gconstpointer data)
+{
+  DeeModelIter *r0, *r1, *r2, *r3, *r4, *r5;
+  DeeFilter    *collator = dee_filter_new_collator_desc (1);
+  DeeModel     *m = dee_filter_model_new (collator, fix->model);
+
+  g_free (collator);
+
+  /* Test alphabetic sorting after initial construction */
+  r0 = dee_model_get_iter_at_row (m, 0);
+  r1 = dee_model_get_iter_at_row (m, 1);
+  r2 = dee_model_get_iter_at_row (m, 2);
+  g_assert_cmpstr ("Zero", ==, dee_model_get_string (m, r0, 1));
+  g_assert_cmpstr ("Two", ==, dee_model_get_string (m, r1, 1));
+  g_assert_cmpstr ("One", ==, dee_model_get_string (m, r2, 1));
+
+  /* Test alphabetic sorting after updates */
+  dee_model_append (fix->model, 3, "Three");
+  dee_model_append (fix->model, 4, "Four");
+  r0 = dee_model_get_iter_at_row (m, 0);
+  r1 = dee_model_get_iter_at_row (m, 1);
+  r2 = dee_model_get_iter_at_row (m, 2);
+  r3 = dee_model_get_iter_at_row (m, 3);
+  r4 = dee_model_get_iter_at_row (m, 4);
+  g_assert_cmpstr ("Zero", ==, dee_model_get_string (m, r0, 1));
+  g_assert_cmpstr ("Two", ==, dee_model_get_string (m, r1, 1));
+  g_assert_cmpstr ("Three", ==, dee_model_get_string (m, r2, 1));
+  g_assert_cmpstr ("One", ==, dee_model_get_string (m, r3, 1));
+  g_assert_cmpstr ("Four", ==, dee_model_get_string (m, r4, 1));
+
+  /* Appending to the end of the sorted model is a special case in the code,
+   * so double check on that... */
+  dee_model_append (fix->model, 5, "Zzzz");
+  r0 = dee_model_get_iter_at_row (m, 0);
+  r5 = dee_model_get_iter_at_row (m, 5);
+  g_assert_cmpstr ("Four", ==, dee_model_get_string (m, r5, 1));
+  g_assert_cmpstr ("Zzzz", ==, dee_model_get_string (m, r0, 1));
+
+  g_object_unref (m);
+}
+
 static void
 _test_orig_ordering (FilterFixture *fix,
                      DeeFilter     *filter)
