@@ -22,6 +22,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <dee.h>
+#include <stdlib.h>
 
 typedef struct
 {
@@ -40,6 +41,7 @@ static void test_insert_at_pos   (RowsFixture *fix, gconstpointer data);
 static void test_insert_at_iter  (RowsFixture *fix, gconstpointer data);
 static void test_prepend         (RowsFixture *fix, gconstpointer data);
 static void test_no_transfer     (RowsFixture *fix, gconstpointer data);
+static void test_illegal_access  (RowsFixture *fix, gconstpointer data);
 
 void
 test_model_rows_create_suite (void)
@@ -76,7 +78,11 @@ test_model_rows_create_suite (void)
               seq_rows_setup, test_no_transfer, seq_rows_teardown);
   g_test_add (PROXY_DOMAIN"/NoTransfer", RowsFixture, 0,
               proxy_rows_setup, test_no_transfer, proxy_rows_teardown);
-              
+
+  g_test_add (SEQ_DOMAIN"/IllegalAccess", RowsFixture, 0,
+              seq_rows_setup, test_illegal_access, seq_rows_teardown);
+  g_test_add (PROXY_DOMAIN"/IllegalAccess", RowsFixture, 0,
+              proxy_rows_setup, test_illegal_access, proxy_rows_teardown);
 }
 
 static void
@@ -272,3 +278,30 @@ test_no_transfer (RowsFixture *fix, gconstpointer data)
   dee_model_get (fix->model, iter, NULL, &str1, -1);
   g_assert_cmpstr (str1, ==, "test");
 }
+
+/* Try to get and set values from a removed row */
+static void
+test_illegal_access (RowsFixture *fix, gconstpointer data)
+{
+  DeeModelIter *iter;
+
+  dee_model_append (fix->model, 1, "Hello");
+  iter = dee_model_append (fix->model, 1, "Mary");
+  dee_model_append (fix->model, 1, "Lou");
+
+  dee_model_remove (fix->model, iter);
+
+  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
+    {
+      g_assert_cmpstr (dee_model_get_string (fix->model, iter, 1), ==, "Mary");
+      exit (0); /* successful test run */
+    }
+  g_test_trap_assert_failed ();
+
+  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
+    {
+      dee_model_set (fix->model, iter, 27, "Marie");
+      exit (0); /* successful test run */
+    }
+  g_test_trap_assert_failed ();
+}
